==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/nb/Filter.js <==
({
	"clearFilterDialogTitle": "Tøm filter",
	"filterDefDialogTitle": "Filter",
	"ruleTitleTemplate": "Regel ${0}",
	
	"conditionEqual": "er lik",
	"conditionNotEqual": "er ikke lik",
	"conditionLess": "er mindre enn",
	"conditionLessEqual": "mindre enn eller lik",
	"conditionLarger": "er større enn",
	"conditionLargerEqual": "større enn eller lik",
	"conditionContains": "inneholder",
	"conditionIs": "er",
	"conditionStartsWith": "starter med",
	"conditionEndWith": "slutter med",
	"conditionNotContain": "inneholder ikke",
	"conditionIsNot": "er ikke",
	"conditionNotStartWith": "starter ikke med",
	"conditionNotEndWith": "slutter ikke med",
	"conditionBefore": "før",
	"conditionAfter": "etter",
	"conditionRange": "område",
	"conditionIsEmpty": "er tom",
	
	"all": "alle",
	"any": "minst en",
	"relationAll": "alle regler",
	"waiRelAll": "Samsvar med alle disse reglene:",
	"relationAny": "minst en regel",
	"waiRelAny": "Samsvar med minst en av disse reglene:",
	"relationMsgFront": "Samsvar med",
	"relationMsgTail": "",
	"and": "og",
	"or": "eller",
	
	"addRuleButton": "Legg til regel",
	"waiAddRuleButton": "Legg til en ny regel",
	"removeRuleButton": "Fjern regel",
	"waiRemoveRuleButtonTemplate": "Fjern regel ${0}",
	
	"cancelButton": "Avbryt",
	"waiCancelButton": "Avbryt denne dialogboksen",
	"clearButton": "Tøm",
	"waiClearButton": "Tøm filteret",
	"filterButton": "Filtrer",
	"waiFilterButton": "Send filteret",
	
	"columnSelectLabel": "Kolonne",
	"waiColumnSelectTemplate": "Kolonne for regel ${0}",
	"conditionSelectLabel": "Betingelse",
	"waiConditionSelectTemplate": "Betingelse for regel ${0}",
	"valueBoxLabel": "Verdi",
	"waiValueBoxTemplate": "Oppgi verdi som skal filtreres for regel ${0}",
	
	"rangeTo": "til",
	"rangeTemplate": "fra ${0} til ${1}",
	
	"statusTipHeaderColumn": "Kolonne",
	"statusTipHeaderCondition": "Regler",
	"statusTipTitle": "Filterlinje",
	"statusTipMsg": "Klikk på filterlinjen her for å filtrere på verdiene i ${0}.",
	"anycolumn": "enhver kolonne",
	"statusTipTitleNoFilter": "Filterlinje",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelPre": "Samsvar med",
	"statusTipRelPost": "regler.",
	
	"defaultItemsName": "elementer",
	"filterBarMsgHasFilterTemplate": "${0} av ${1} ${2} vist.",
	"filterBarMsgNoFilterTemplate": "Ikke brukt filter",
	
	"filterBarDefButton": "Definer filter",
	"waiFilterBarDefButton": "Filtrer tabellen",
	"a11yFilterBarDefButton": "Filtrer...",
	"filterBarClearButton": "Tøm filter",
	"waiFilterBarClearButton": "Tøm filteret",
	"closeFilterBarBtn": "Lukk filterlinjen",
	
	"clearFilterMsg": "Dette fjerner filteret og viser alle tilgjengelige poster.",
	"anyColumnOption": "Minst en kolonne",
	
	"trueLabel": "Sann",
	"falseLabel": "Usann"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/nb/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Tøm filter",
	"filterDefDialogTitle": "Filter",
	"ruleTitleTemplate": "Regel ${0}",
	
	"conditionEqual": "er lik",
	"conditionNotEqual": "er ikke lik",
	"conditionLess": "er mindre enn",
	"conditionLessEqual": "mindre enn eller lik",
	"conditionLarger": "er større enn",
	"conditionLargerEqual": "større enn eller lik",
	"conditionContains": "inneholder",
	"conditionIs": "er",
	"conditionStartsWith": "starter med",
	"conditionEndWith": "slutter med",
	"conditionNotContain": "inneholder ikke",
	"conditionIsNot": "er ikke",
	"conditionNotStartWith": "starter ikke med",
	"conditionNotEndWith": "slutter ikke med",
	"conditionBefore": "før",
	"conditionAfter": "etter",
	"conditionRange": "område",
	"conditionIsEmpty": "er tom",
	
	"all": "alle",
	"any": "minst en",
	"relationAll": "alle regler",
	"waiRelAll": "Samsvar med alle disse reglene:",
	"relationAny": "minst en regel",
	"waiRelAny": "Samsvar med minst en av disse reglene:",
	"relationMsgFront": "Samsvar med",
	"relationMsgTail": "",
	"and": "og",
	"or": "eller",
	
	"addRuleButton": "Legg til regel",
	"waiAddRuleButton": "Legg til en ny regel",
	"removeRuleButton": "Fjern regel",
	"waiRemoveRuleButtonTemplate": "Fjern regel ${0}",
	
	"cancelButton": "Avbryt",
	"waiCancelButton": "Avbryt denne dialogboksen",
	"clearButton": "Tøm",
	"waiClearButton": "Tøm filteret",
	"filterButton": "Filtrer",
	"waiFilterButton": "Send filteret",
	
	"columnSelectLabel": "Kolonne",
	"waiColumnSelectTemplate": "Kolonne for regel ${0}",
	"conditionSelectLabel": "Betingelse",
	"waiConditionSelectTemplate": "Betingelse for regel ${0}",
	"valueBoxLabel": "Verdi",
	"waiValueBoxTemplate": "Oppgi verdi som skal filtreres for regel ${0}",
	
	"rangeTo": "til",
	"rangeTemplate": "fra ${0} til ${1}",
	
	"statusTipHeaderColumn": "Kolonne",
	"statusTipHeaderCondition": "Regler",
	"statusTipTitle": "Filterlinje",
	"statusTipMsg": "Klikk på filterlinjen her for å filtrere på verdiene i ${0}.",
	"anycolumn": "enhver kolonne",
	"statusTipTitleNoFilter": "Filterlinje",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelAny": "Samsvar med minst en regel.",
	"statusTipRelAll": "Samsvar med alle regler.",
	
	"defaultItemsName": "elementer",
	"filterBarMsgHasFilterTemplate": "${0} av ${1} ${2} vist.",
	"filterBarMsgNoFilterTemplate": "Ikke brukt filter",
	
	"filterBarDefButton": "Definer filter",
	"waiFilterBarDefButton": "Filtrer tabellen",
	"a11yFilterBarDefButton": "Filtrer...",
	"filterBarClearButton": "Tøm filter",
	"waiFilterBarClearButton": "Tøm filteret",
	"closeFilterBarBtn": "Lukk filterlinjen",
	
	"clearFilterMsg": "Dette fjerner filteret og viser alle tilgjengelige poster.",
	"anyColumnOption": "Minst en kolonne",
	
	"trueLabel": "Sann",
	"falseLabel": "Usann"
})
//end v1.x content
);
